==> openshift-model-config-6.2.0-sources.jar: io/fabric8/openshift/api/model/config/v1/SchedulerSpecFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface SchedulerSpecFluent<A extends SchedulerSpecFluent<A>> extends Fluent<A>{
  public String getDefaultNodeSelector();
  public A withDefaultNodeSelector(String defaultNodeSelector);
  public Boolean hasDefaultNodeSelector();
  public Boolean getMastersSchedulable();
  public A withMastersSchedulable(Boolean mastersSchedulable);
  public Boolean hasMastersSchedulable();
  
  /**
   * This method has been deprecated, please use method buildPolicy instead.
   * @return The buildable object.
   */
  @Deprecated
  public ConfigMapNameReference getPolicy();
  public ConfigMapNameReference buildPolicy();
  public A withPolicy(ConfigMapNameReference policy);
  public Boolean hasPolicy();
  public A withNewPolicy(String name);
  public SchedulerSpecFluent.PolicyNested<A> withNewPolicy();
  public SchedulerSpecFluent.PolicyNested<A> withNewPolicyLike(ConfigMapNameReference item);
  public SchedulerSpecFluent.PolicyNested<A> editPolicy();
  public SchedulerSpecFluent.PolicyNested<A> editOrNewPolicy();
  public SchedulerSpecFluent.PolicyNested<A> editOrNewPolicyLike(ConfigMapNameReference item);
  public String getProfile();
  public A withProfile(String profile);
  public Boolean hasProfile();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public A withMastersSchedulable();
  public interface PolicyNested<N> extends Nested<N>,ConfigMapNameReferenceFluent<SchedulerSpecFluent.PolicyNested<N>>{
    public N and();
    public N endPolicy();
    
  }
  
}

==> openshift-model-config-6.7.2-sources.jar: io/fabric8/openshift/api/model/config/v1/SchedulerSpecFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface SchedulerSpecFluent<A extends SchedulerSpecFluent<A>> extends Fluent<A>{
  public String getDefaultNodeSelector();
  public A withDefaultNodeSelector(String defaultNodeSelector);
  public Boolean hasDefaultNodeSelector();
  public Boolean getMastersSchedulable();
  public A withMastersSchedulable(Boolean mastersSchedulable);
  public Boolean hasMastersSchedulable();
  
  /**
   * This method has been deprecated, please use method buildPolicy instead.
   * @return The buildable object.
   */
  @Deprecated
  public ConfigMapNameReference getPolicy();
  public ConfigMapNameReference buildPolicy();
  public A withPolicy(ConfigMapNameReference policy);
  public Boolean hasPolicy();
  public A withNewPolicy(String name);
  public SchedulerSpecFluent.PolicyNested<A> withNewPolicy();
  public SchedulerSpecFluent.PolicyNested<A> withNewPolicyLike(ConfigMapNameReference item);
  public SchedulerSpecFluent.PolicyNested<A> editPolicy();
  public SchedulerSpecFluent.PolicyNested<A> editOrNewPolicy();
  public SchedulerSpecFluent.PolicyNested<A> editOrNewPolicyLike(ConfigMapNameReference item);
  public String getProfile();
  public A withProfile(String profile);
  public Boolean hasProfile();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public A withMastersSchedulable();
  public interface PolicyNested<N> extends Nested<N>,ConfigMapNameReferenceFluent<SchedulerSpecFluent.PolicyNested<N>>{
    public N and();
    public N endPolicy();
    
  }
  
}
